<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sl">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <location filename="../mainwindow.cpp" line="53"/>
        <location filename="../mainwindow.cpp" line="244"/>
        <location filename="../mainwindow.cpp" line="289"/>
        <source>MX Cleanup</source>
        <translation>MX Čiščenje</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="26"/>
        <source>Clean Folders</source>
        <translation>Očisti imenike</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="86"/>
        <source>Delete Logs</source>
        <translation>Izbriši dnevnike</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="98"/>
        <source>Old logs</source>
        <translation>Stari dnevniki</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="117"/>
        <source>All logs</source>
        <translation>Vsi dnevniki</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="130"/>
        <location filename="../mainwindow.ui" line="387"/>
        <location filename="../mainwindow.ui" line="451"/>
        <source>Don&apos;t empty</source>
        <translation>Ne briši</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="192"/>
        <source>Display help </source>
        <translation>Prikaži pomoč</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="195"/>
        <source>Help</source>
        <translation>Pomoč</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="202"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="231"/>
        <source>About this application</source>
        <translation>O tem programu</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="234"/>
        <source>About...</source>
        <translation>O programu...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="241"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="273"/>
        <source>Quit application</source>
        <translation>Zapri aplikacijo</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="276"/>
        <source>Close</source>
        <translation>Zapri</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="283"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="321"/>
        <source>Apply</source>
        <translation>Potrdi</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="349"/>
        <source>Empty Trash</source>
        <translation>Izprazni smeti</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="364"/>
        <source>Selected user</source>
        <translation>Izbrani uporabnik</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="380"/>
        <source>All users</source>
        <translation>Vsi uporabniki</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="416"/>
        <source>Clear APT Cache</source>
        <translation>Očisti medpomnilnik APT</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="428"/>
        <source>Old files</source>
        <translation>Stare datoteke</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="444"/>
        <source>All files</source>
        <translation>Vse datoteke</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="480"/>
        <source>Free Disk Space for User</source>
        <translation>Sprosti prostor na disku za uporabnika</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="492"/>
        <location filename="../mainwindow.ui" line="505"/>
        <source>Select user to repair</source>
        <translation>Izberi uporabnika za popravilo</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="508"/>
        <source>Select user:</source>
        <translation>Izberi uporabnika:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="524"/>
        <source>Graphical Tool for Analyzing Disk Usage</source>
        <translation>Grafično orodje za analiziranje rabe diska</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="530"/>
        <source>Run Disk Usage Analyzer</source>
        <translation>Zaženi analizo rabe diska</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="544"/>
        <source>Schedule</source>
        <translation>Termin</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="556"/>
        <source>No automatic clean</source>
        <translation>Brez samodejnega čiščenja</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="563"/>
        <source>Daily</source>
        <translation>Dnevno</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="570"/>
        <source>Weekly</source>
        <translation>Tedensko</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="577"/>
        <source>Monthly</source>
        <translation>Mesečno</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="235"/>
        <source>Done</source>
        <translation>Zaključeno</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="236"/>
        <source>Cleanup command done</source>
        <translation>Čiščenje je končano</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="237"/>
        <source>%1 MiB were freed</source>
        <translation>%1 MiB je bilo sproščeno</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="244"/>
        <source>About</source>
        <translation>O programu</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="245"/>
        <source>Version: </source>
        <translation>Različica:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="246"/>
        <source>Quick and safe removal of old files</source>
        <translation>Hitro in varno odstranjevanje starih datotek</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="248"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="249"/>
        <location filename="../mainwindow.cpp" line="259"/>
        <source>License</source>
        <translation>Licenca</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="250"/>
        <source>Changelog</source>
        <translation>Dnevnik sprememb</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="251"/>
        <source>Cancel</source>
        <translation>Prekliči</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="271"/>
        <source>&amp;Close</source>
        <translation>&amp;Zapri</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <location filename="../main.cpp" line="52"/>
        <source>You must run this program as root.</source>
        <translation>Ta program morate zagnati kot root</translation>
    </message>
</context>
</TS>
